==> qmmp_0.2.3.orig.tar.gz: qmmp-0.2.3/src/plugins/Input/mpc/translations/mpc_plugin_de.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS><TS version="1.1" language="de">
<context>
    <name>DecoderMPCFactory</name>
    <message>
        <location filename="../decodermpcfactory.cpp" line="26"/>
        <source>Musepack Plugin</source>
        <translation>Musepack plugin</translation>
    </message>
    <message>
        <location filename="../decodermpcfactory.cpp" line="28"/>
        <source>Musepack Files</source>
        <translation>Musepack Dateien</translation>
    </message>
    <message>
        <location filename="../decodermpcfactory.cpp" line="82"/>
        <source>About Musepack Audio Plugin</source>
        <translation>Über Musepack Audio Plugin</translation>
    </message>
    <message>
        <location filename="../decodermpcfactory.cpp" line="83"/>
        <source>Qmmp Musepack Audio Plugin</source>
        <translation>Qmmp Musepack Audio Plugin</translation>
    </message>
    <message>
        <location filename="../decodermpcfactory.cpp" line="84"/>
        <source>Writen by: Ilya Kotov &lt;forkotov02@hotmail.ru&gt;</source>
        <translation>Autor: Ilja Kotov &lt;forkotov02@hotmail.ru&gt;</translation>
    </message>
</context>
<context>
    <name>DetailsDialog</name>
    <message>
        <location filename="../detailsdialog.cpp" line="63"/>
        <source>kbps</source>
        <translation>kbps</translation>
    </message>
    <message>
        <location filename="../detailsdialog.cpp" line="59"/>
        <source>Hz</source>
        <translation>Hz</translation>
    </message>
    <message>
        <location filename="../detailsdialog.cpp" line="66"/>
        <source>KB</source>
        <translation>KB</translation>
    </message>
    <message>
        <location filename="../detailsdialog.ui" line="13"/>
        <source>Details</source>
        <translation>Details</translation>
    </message>
    <message>
        <location filename="../detailsdialog.ui" line="136"/>
        <source>File size:</source>
        <translation>Dateigröße:</translation>
    </message>
    <message>
        <location filename="../detailsdialog.ui" line="183"/>
        <source>-</source>
        <translation>-</translation>
    </message>
    <message>
        <location filename="../detailsdialog.ui" line="103"/>
        <source>Sample rate:</source>
        <translation>Abtastrate:</translation>
    </message>
    <message>
        <location filename="../detailsdialog.ui" line="299"/>
        <source>Save</source>
        <translation>Speichern</translation>
    </message>
    <message>
        <location filename="../detailsdialog.ui" line="270"/>
        <source>Track number:</source>
        <translation>Titelnummer:</translation>
    </message>
    <message>
        <location filename="../detailsdialog.ui" line="257"/>
        <source>Year:</source>
        <translation>Jahr:</translation>
    </message>
    <message>
        <location filename="../detailsdialog.ui" line="283"/>
        <source>Genre:</source>
        <translation>Genre:</translation>
    </message>
    <message>
        <location filename="../detailsdialog.ui" line="244"/>
        <source>Comment:</source>
        <translation>Kommentar:</translation>
    </message>
    <message>
        <location filename="../detailsdialog.ui" line="231"/>
        <source>Album:</source>
        <translation>Album:</translation>
    </message>
    <message>
        <location filename="../detailsdialog.ui" line="218"/>
        <source>Artist:</source>
        <translation>Künstler:</translation>
    </message>
    <message>
        <location filename="../detailsdialog.ui" line="205"/>
        <source>Title:</source>
        <translation>Titel:</translation>
    </message>
    <message>
        <location filename="../detailsdialog.ui" line="322"/>
        <source>Close</source>
        <translation>Schließen</translation>
    </message>
    <message>
        <location filename="../detailsdialog.ui" line="19"/>
        <source>File path:</source>
        <translation>Dateipfad:</translation>
    </message>
    <message>
        <location filename="../detailsdialog.ui" line="86"/>
        <source>Length:</source>
        <translation>Länge:</translation>
    </message>
    <message>
        <location filename="../detailsdialog.ui" line="123"/>
        <source>Channels:</source>
        <translation>Kanäle:</translation>
    </message>
    <message>
        <location filename="../detailsdialog.ui" line="42"/>
        <source>Musepack Info</source>
        <translation>Musepack Info</translation>
    </message>
    <message>
        <location filename="../detailsdialog.ui" line="146"/>
        <source>Bitrate:</source>
        <translation>Bitrate:</translation>
    </message>
    <message>
        <location filename="../detailsdialog.ui" line="173"/>
        <source>Stream version:</source>
        <translation>Stream version:</translation>
    </message>
    <message>
        <location filename="../detailsdialog.ui" line="199"/>
        <source>APE Tag</source>
        <translation>APE Tag</translation>
    </message>
</context>
</TS>

==> qmmp_0.3.1.orig.tar.gz: qmmp-0.3.1/src/plugins/Input/mpc/translations/mpc_plugin_de.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="de">
<context>
    <name>DecoderMPCFactory</name>
    <message>
        <location filename="../decodermpcfactory.cpp" line="46"/>
        <source>Musepack Plugin</source>
        <translation>Musepack-Modul</translation>
    </message>
    <message>
        <location filename="../decodermpcfactory.cpp" line="48"/>
        <source>Musepack Files</source>
        <translation>Musepack-Dateien</translation>
    </message>
    <message>
        <location filename="../decodermpcfactory.cpp" line="103"/>
        <source>About Musepack Audio Plugin</source>
        <translation>Über Musepack-Audio-Modul</translation>
    </message>
    <message>
        <location filename="../decodermpcfactory.cpp" line="104"/>
        <source>Qmmp Musepack Audio Plugin</source>
        <translation>Qmmp Musepack-Audio-Modul</translation>
    </message>
    <message>
        <location filename="../decodermpcfactory.cpp" line="105"/>
        <source>Writen by: Ilya Kotov &lt;forkotov02@hotmail.ru&gt;</source>
        <translation>Autor: Ilya Kotov &lt;forkotov02@hotmail.ru&gt;</translation>
    </message>
</context>
<context>
    <name>DetailsDialog</name>
    <message>
        <location filename="../detailsdialog.cpp" line="63"/>
        <source>kbps</source>
        <translation>kbps</translation>
    </message>
    <message>
        <location filename="../detailsdialog.cpp" line="59"/>
        <source>Hz</source>
        <translation>Hz</translation>
    </message>
    <message>
        <location filename="../detailsdialog.cpp" line="66"/>
        <source>KB</source>
        <translation>KB</translation>
    </message>
    <message>
        <location filename="../detailsdialog.ui" line="13"/>
        <source>Details</source>
        <translation>Details</translation>
    </message>
    <message>
        <location filename="../detailsdialog.ui" line="136"/>
        <source>File size:</source>
        <translation>Dateigröße:</translation>
    </message>
    <message>
        <location filename="../detailsdialog.ui" line="79"/>
        <location filename="../detailsdialog.ui" line="96"/>
        <location filename="../detailsdialog.ui" line="113"/>
        <location filename="../detailsdialog.ui" line="159"/>
        <location filename="../detailsdialog.ui" line="166"/>
        <location filename="../detailsdialog.ui" line="183"/>
        <source>-</source>
        <translation>-</translation>
    </message>
    <message>
        <location filename="../detailsdialog.ui" line="103"/>
        <source>Sample rate:</source>
        <translation>Abtastrate:</translation>
    </message>
    <message>
        <location filename="../detailsdialog.ui" line="299"/>
        <source>Save</source>
        <translation>Speichern</translation>
    </message>
    <message>
        <location filename="../detailsdialog.ui" line="270"/>
        <source>Track number:</source>
        <translation>Titelnummer:</translation>
    </message>
    <message>
        <location filename="../detailsdialog.ui" line="257"/>
        <source>Year:</source>
        <translation>Jahr:</translation>
    </message>
    <message>
        <location filename="../detailsdialog.ui" line="283"/>
        <source>Genre:</source>
        <translation>Genre:</translation>
    </message>
    <message>
        <location filename="../detailsdialog.ui" line="244"/>
        <source>Comment:</source>
        <translation>Kommentar:</translation>
    </message>
    <message>
        <location filename="../detailsdialog.ui" line="231"/>
        <source>Album:</source>
        <translation>Album:</translation>
    </message>
    <message>
        <location filename="../detailsdialog.ui" line="218"/>
        <source>Artist:</source>
        <translation>Interpret:</translation>
    </message>
    <message>
        <location filename="../detailsdialog.ui" line="205"/>
        <source>Title:</source>
        <translation>Titel:</translation>
    </message>
    <message>
        <location filename="../detailsdialog.ui" line="322"/>
        <source>Close</source>
        <translation>Schließen</translation>
    </message>
    <message>
        <location filename="../detailsdialog.ui" line="19"/>
        <source>File path:</source>
        <translation>Dateipfad:</translation>
    </message>
    <message>
        <location filename="../detailsdialog.ui" line="86"/>
        <source>Length:</source>
        <translation>Länge:</translation>
    </message>
    <message>
        <location filename="../detailsdialog.ui" line="123"/>
        <source>Channels:</source>
        <translation>Kanäle:</translation>
    </message>
    <message>
        <location filename="../detailsdialog.ui" line="42"/>
        <source>Musepack Info</source>
        <translation>Musepack-Info</translation>
    </message>
    <message>
        <location filename="../detailsdialog.ui" line="146"/>
        <source>Bitrate:</source>
        <translation>Bitrate:</translation>
    </message>
    <message>
        <location filename="../detailsdialog.ui" line="173"/>
        <source>Stream version:</source>
        <translation>Stream-Version:</translation>
    </message>
    <message>
        <location filename="../detailsdialog.ui" line="199"/>
        <source>APE Tag</source>
        <translation>APE-Tag</translation>
    </message>
</context>
</TS>
